
#ifndef BUFFER_H
#define BUFFER_H

void *buffer_new(unsigned char *, int);
void buffer_free(void *);
int buffer_find_string(void *, char *);
void buffer_skip_bytes(void *, int);
int buffer_getlen(void *);
int buffer_getloc(void *);
void buffer_setloc(void *, int);
unsigned char *buffer_getbuf(void *);
char buffer_read_char(void *);
unsigned char buffer_read_uchar(void *);
int buffer_read_int(void *);
int buffer_read_int_print(void *);
unsigned int buffer_read_uint(void *);
int buffer_read_short(void *);
int buffer_read_ushort(void *);
int buffer_read_byte(void *);
int buffer_read_ubyte(void *);
float buffer_read_float(void *);
int buffer_eof(void *);
char *buffer_read_intstring(void *);
char *buffer_read_nstring(void *, int);
char *buffer_read_string4(void *);
char *buffer_read_bytes(void *, int);
void buffer_read_bytes_in(void *, int, char *);

#endif
